#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
pub const INFINITY: f64 = f64::INFINITY as _;
pub const NEG_INFINITY: f64 = f64::NEG_INFINITY as _;
pub const NAN: f64 = f64::NAN as _;
pub const F32_INFINITY: f32 = f64::INFINITY as _;
pub const F32_NEG_INFINITY: f32 = f64::NEG_INFINITY as _;
pub const F32_NAN: f32 = f64::NAN as _;
