#define INFINITY (1.0f/0.0f)
#define NEG_INFINITY (-1.0f/0.0f)
#define NAN (0.0f/0.0f)

static const float F32_INFINITY = 1.0f / 0.0f;
static const float F32_NEG_INFINITY = -1.0f / 0.0f;
static const float F32_NAN = 0.0f / 0.0f;
